@@ -93,8 +93,21 @@ DateTime::Astro - Functions For Astromical Calendars
 
 =head1 DESCRIPTION
 
-DateTime::Astro implements functions used in astronomical calendars, such
-as calculation of lunar longitudea and solar longitude.
+DateTime::Astro implements functions used in astronomical calendars:
+
+=over 4 
+
+=item Solar Longitude
+
+=item Solar Terms
+
+=item Lunar Longitude
+
+=item New Moons
+
+=item ...etc
+
+=back
 
 This module is best used in environments where a C compiler and the MPFR arbitrary precision math library is installed. It can fallback to using Math::BigInt, but that would pretty much render it useless because of its speed and loss of accuracy that may creep up while doing Perl to C struct conversions.
 
@@ -102,6 +115,10 @@ This module is best used in environments where a C compiler and the MPFR arbitra
 
 This module works, but there are several caveats you should be aware of:
 
+=head2 KNOWN ISSUES
+
+There are several edge cases that the test suite already unveils, current in solar term calculations. only 1% of the dates are affected, so I opted to make them TODO. If you are interested, please see xt/101_solar_term.t. Patches are very much appreciated.
+
 =head2 MPFR Is Required / PurePerl Version Not Functional
 
 There /is/ a HALF BAKED Pure Perl implmentation bundled with this distribution, but at this point please consider it UNUSABLE. This sort of calculation requires the speed and efficiency of a C library anyway.
